@@ -2,7 +2,7 @@ package Finance::Nadex;
 
 use strict;
 use warnings;
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use LWP::UserAgent;
 use JSON;
@@ -11,7 +11,7 @@ use Finance::Nadex::Order;
 use Finance::Nadex::Position;
 use Finance::Nadex::Contract;
 
-use constant LOGIN_URL              => 'https://www.nadex.com/iDeal/login';
+use constant LOGIN_URL              => 'https://www.nadex.com/iDeal/v2/security/authenticate';
 use constant SEND_ORDER_URL         => 'https://www.nadex.com/iDeal/dma/workingorders';
 use constant RETRIEVE_ORDERS_URL    => 'https://www.nadex.com/iDeal/orders/workingorders';
 use constant RETRIEVE_ORDER_URL     => 'https://www.nadex.com/iDeal/markets/details/workingorders';
@@ -166,6 +166,8 @@ sub get_contract {
     return Finance::Nadex::Contract::_new({  instrumentType => $epic_ref->{instrument}{instrumentType}, epic => $args{epic},
     	                              displayOffer => $epic_ref->{marketSnapshot}{displayOffer},
     	                              displayBid => $epic_ref->{marketSnapshot}{displayBid},
+                                      displayBidSize => $epic_ref->{marketSnapshot}{displayBidSize},
+                                      displayOfferSize => $epic_ref->{marketSnapshot}{displayOfferSize},
     	                              instrumentName => $epic_ref->{instrument}{marketName},
     	                              displayPeriod => $epic_ref->{instrument}{displayPrompt} } );
 
@@ -486,9 +488,7 @@ sub login {
 
     my $login_content = qq~
      { 
-        "clientApplication" : "dxd", 
-        "clientPlatform": "ANDROID_PHONE", 
-        "clientVersion": "1.13.2",
+        "advertisingId" : "",
         "password": "$self->{password}",
         "username": "$self->{username}"
      }~;
@@ -672,8 +672,8 @@ sub _post {
     my $response = $self->{user_agent}->post(
         $url,
         clientApplication          => 'dxd',
-        clientPlatform             => 'ANDROID_PHONE',
-        clientVersion              => '1.13.2',
+        clientPlatform             => 'APPLE_TABLET',
+        version                    => '1',
         Accept                     => 'application/json; charset=UTF-8',
         'Content-Type'             => 'application/json; charset=UTF-8',
         'Accept-Encoding'          => 'text/html',
@@ -683,7 +683,7 @@ sub _post {
         'X-IG-DEVICE_OS_VERSION'   => '5.0.1',
         'X-IG-DEVICE_LOCALE'       => 'en_US',
         'X-IG-DEVICE_CARRIER'      => 'AT&T',
-        'X-IG-DEVICE_CONNECTIVITY' => 'WIFI',
+        'X-DEVICE-USER-AGENT'      => 'vendor=Minsk | applicationType=NADEX_PROMO | platform=Android | deviceType=phone | version=2.0.4',
         Host                       => 'www.nadex.com',
         Connection                 => 'Keep-Alive',
         'X-SECURITY-TOKEN'         => $self->{security_token},
